@@ -779,7 +779,7 @@ class Base(Controller):
         help='Manage TODOs using Asana',
         arguments=[
             (['action'],{
-                "help" : "One of {add, ls, dn}",
+                "help" : "One of {add, ls, dn, lsws}",
                 "action": "store"
             }),
             (['-t'],{
@@ -799,7 +799,7 @@ class Base(Controller):
                 "action": "store"
             }),
             (['-ws'],{
-                "help": "Workspace name (e.g. Daily) otherwiwise grabs the first one",
+                "help": "Workspace gid (long numeric) otherwiwise grabs the first one",
                 "action": "store"
             }),
             (['-f'],{
@@ -809,7 +809,8 @@ class Base(Controller):
         ]
     )
     def td(self):
-        from ..ext.asana import add_todo, asana_list_todos, done_todo, fix_past_due
+        from ..ext.asana import add_todo, asana_list_todos, done_todo,  \
+            fix_past_due, asana_list_workspaces
         project = self.app.pargs.p or "Daily"
 
         if self.app.pargs.action=='add':
@@ -822,6 +823,8 @@ class Base(Controller):
             done_todo(self.app.pargs.i)
         elif self.app.pargs.action=='fix':
             fix_past_due(self.app.pargs.p)
+        elif self.app.pargs.action=='lsws':
+            asana_list_workspaces(self.app.pargs.f)
 
         else:
             raise NotImplemented("Action must be one of {add, ls, dn}")
