@@ -7,9 +7,15 @@ import time
 import sys
 pd.options.display.width = 0
 
+# disable pandas warning
+pd.options.mode.chained_assignment = None
+
 # pandas set max column width
 pd.set_option('display.max_colwidth', 75)
 
+def get_subtask_name(row):
+    # [[{'gid': '947951982649945', 'resource_type': 'task'}, {'gid': '947951982649946', 'resource_type': 'task'}]]
+    pass
 
 def user_select_option(message, options):
     option_lst = list(options)
@@ -70,7 +76,9 @@ def get_oauth_token(config):
 
 def get_client(oauth=False):
     with open(os.path.expanduser('~/.dt_config.json')) as f:
-        config = json.load(f)
+        # before loading strip all lines starting with // after leading whitespace is stripped
+        f = '\n'.join([line for line in f.read().splitlines() if not line.strip().startswith('//')])
+        config = json.loads(f)
     
     # check if asana api key exists
     if 'asana_api_key' in config.keys():
@@ -105,7 +113,10 @@ def asana_list_todos(workspace_name,filtering):
     if filtering is None: filtering = 'due'
     
     df = asana_get_todos(workspace_name,filtering)
-    df = df[['gid','name',"due_on", "completed", "notes"]] # projects
+    df = df[['gid','name',"due_on", "completed", "notes", "subtasks"]] # projects
+    
+    # get all subtasks
+    
     
     if filtering == 'done':
         df = df[df['completed'] == True]
@@ -122,6 +133,14 @@ def asana_list_todos(workspace_name,filtering):
         df = asana_get_todos(workspace_name,filtering)
         print(df)
         
+def asana_list_workspaces(filtering):
+    client = get_client(True)
+
+    me = client.users.me()
+    workspaces_df = pd.DataFrame(me['workspaces'])
+    print(workspaces_df)
+    
+    
 def asana_get_todos(workspace_name,filtering):
      # read api key from ~/.dt_config.json
     client = get_client(True)
@@ -134,7 +153,7 @@ def asana_get_todos(workspace_name,filtering):
     # https://developers.asana.com/docs/get-tasks-from-a-project
     # print requests that python is making
 
-    opt_fields='name,due_on,completed,projects,notes'
+    opt_fields='name,due_on,completed,projects,notes,subtasks'
     if filtering!='everyone':
         tasks = list(client.tasks.find_all({"opt_fields":opt_fields}, 
                                            workspace=workspace_id, assignee='me'))
