@@ -1,9 +1,13 @@
 import torch
-import numpy as np
-import matplotlib.pyplot as plt
-from PIL import Image
-from typing import Optional, Callable
-import cv2
+try:
+    import numpy as np
+    import matplotlib.pyplot as plt
+    from PIL import Image
+    from typing import Optional, Callable
+    import cv2
+except ModuleNotFoundError:
+    import os
+    os.system('pip install numPy matplotlib Pillow opencv-python')
 
 # np.set_printoptions(precision=3)
 
